Class: ShellDataReportingApIs::Filters
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ShellDataReportingApIs::Filters
- Defined in:
- lib/shell_data_reporting_ap_is/models/filters.rb
Overview
Filters Model.
Instance Attribute Summary collapse
-
#account_id ⇒ Integer
Account Id (GFN customer id).
-
#account_number ⇒ String
Account Number of the selected account.
-
#card_group_id ⇒ Integer
Card Group Id in GFN.
-
#card_id ⇒ Integer
Unique Card Id in the Shell Card Platform.
-
#card_pan ⇒ String
Full Card PAN.
-
#cards ⇒ Array[Integer]
This entity accepts the list of CardId to filter in the response.
-
#col_co_code ⇒ String
Collecting Company Code (Shell Code) of the selected payer.
-
#col_co_id ⇒ Integer
The Collecting Company Id in the Shell Card Platform.
-
#driver_name ⇒ String
Driver Name (of Card record).
-
#fee_type_id ⇒ Integer
Card Id (i.e. Unique Card Id in GFN).
-
#from_date ⇒ String
From transaction delivery date.
-
#fuel_only ⇒ TrueClass | FalseClass
Is FuelOnly indicator.
-
#hosting_collecting_company_number ⇒ String
Hosting Collecting Company Number of the selected payer.
-
#include_fees ⇒ TrueClass | FalseClass
When passed as ‘true’ then all sales items along with fees will be included in the response and the follwoing filteres will be ignored * InvoiceNumber * InvoiceDate * PostingDateFrom * PostingDateTo.
-
#incoming_site_number ⇒ String
Site Code as configured in GFN.
-
#invoice_date ⇒ String
Returns the billed transaction for the given invoice date.
-
#invoice_from_date ⇒ String
Invoice From Date, this is a search criterion to filter invoiced transactions with invoice date from this date.
-
#invoice_number ⇒ String
Returns the billed transaction for the given invoice number.
-
#invoice_status ⇒ PricedTransactionReqV2InvoiceStatusEnum
The Collecting Company Id in the Shell Card Platform.
-
#invoice_to_date ⇒ String
Invoice To Date, this is a search criterion to filter invoiced transactions with invoice date until this date.
-
#is_multipayer ⇒ TrueClass | FalseClass
If true then returns all the data linked tothe payer group of the provided PayerNumberin the request.
-
#line_item_description ⇒ String
Item identifier in the transaction.
-
#payer_number ⇒ String
Payer Number of the selected payer.
-
#period ⇒ PricedTransactionReqV2PeriodEnum
To transaction delivery date.
-
#posting_date_from ⇒ String
Transaction posting start date and time.
-
#posting_date_to ⇒ String
Transaction posting end date and time.
-
#product_code ⇒ String
Product Code – Global as per GFN configuration.
-
#product_name ⇒ String
Product Name – Global as per GFN configuration.
-
#purchased_in_country ⇒ String
Network Delco PurchasedCountryName.
-
#purchased_in_country_code ⇒ String
Purchased InCountryCode.
-
#search ⇒ String
Search based on DriverName or VRN.
-
#site_code ⇒ String
Site Code in GFN.
-
#site_group_id ⇒ Integer
Site Group Id in GFN.
-
#sort_order ⇒ PricedTransactionReqV2SortOrderEnum
This entity accepts the list of CardId to filter in the response.
-
#to_date ⇒ String
To transaction delivery date.
-
#transaction_id ⇒ String
Unique id of the transaction that may include one or more salesitems.
-
#transaction_item_id ⇒ String
Unique id of the transaction that may include one or more salesitems.
-
#valid_invoice_date_only ⇒ TrueClass | FalseClass
When passed as ‘True’ the transactions records with report date not equal to 9999-12-30 will be returned.
-
#vehicle_registration_number ⇒ String
Vehicle Registration (of Card record).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(col_co_code = nil, invoice_status = nil, payer_number = nil, col_co_id = SKIP, account_id = SKIP, account_number = SKIP, driver_name = SKIP, card_id = SKIP, card_group_id = SKIP, card_pan = SKIP, product_code = SKIP, product_name = SKIP, site_code = SKIP, incoming_site_number = SKIP, invoice_date = SKIP, invoice_number = SKIP, purchased_in_country_code = SKIP, purchased_in_country = SKIP, site_group_id = SKIP, vehicle_registration_number = SKIP, fee_type_id = SKIP, line_item_description = SKIP, cards = SKIP, sort_order = SKIP, from_date = SKIP, to_date = SKIP, period = SKIP, posting_date_from = SKIP, posting_date_to = SKIP, transaction_item_id = SKIP, fuel_only = false, include_fees = SKIP, is_multipayer = SKIP, valid_invoice_date_only = false, invoice_from_date = SKIP, invoice_to_date = SKIP, hosting_collecting_company_number = SKIP, search = SKIP, transaction_id = SKIP) ⇒ Filters
constructor
A new instance of Filters.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(col_co_code = nil, invoice_status = nil, payer_number = nil, col_co_id = SKIP, account_id = SKIP, account_number = SKIP, driver_name = SKIP, card_id = SKIP, card_group_id = SKIP, card_pan = SKIP, product_code = SKIP, product_name = SKIP, site_code = SKIP, incoming_site_number = SKIP, invoice_date = SKIP, invoice_number = SKIP, purchased_in_country_code = SKIP, purchased_in_country = SKIP, site_group_id = SKIP, vehicle_registration_number = SKIP, fee_type_id = SKIP, line_item_description = SKIP, cards = SKIP, sort_order = SKIP, from_date = SKIP, to_date = SKIP, period = SKIP, posting_date_from = SKIP, posting_date_to = SKIP, transaction_item_id = SKIP, fuel_only = false, include_fees = SKIP, is_multipayer = SKIP, valid_invoice_date_only = false, invoice_from_date = SKIP, invoice_to_date = SKIP, hosting_collecting_company_number = SKIP, search = SKIP, transaction_id = SKIP) ⇒ Filters
Returns a new instance of Filters.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 307 def initialize(col_co_code = nil, invoice_status = nil, payer_number = nil, col_co_id = SKIP, account_id = SKIP, account_number = SKIP, driver_name = SKIP, card_id = SKIP, card_group_id = SKIP, card_pan = SKIP, product_code = SKIP, product_name = SKIP, site_code = SKIP, incoming_site_number = SKIP, invoice_date = SKIP, invoice_number = SKIP, purchased_in_country_code = SKIP, purchased_in_country = SKIP, site_group_id = SKIP, vehicle_registration_number = SKIP, fee_type_id = SKIP, line_item_description = SKIP, cards = SKIP, sort_order = SKIP, from_date = SKIP, to_date = SKIP, period = SKIP, posting_date_from = SKIP, posting_date_to = SKIP, transaction_item_id = SKIP, fuel_only = false, include_fees = SKIP, is_multipayer = SKIP, valid_invoice_date_only = false, invoice_from_date = SKIP, invoice_to_date = SKIP, hosting_collecting_company_number = SKIP, search = SKIP, transaction_id = SKIP) @col_co_code = col_co_code @col_co_id = col_co_id unless col_co_id == SKIP @invoice_status = invoice_status @payer_number = payer_number @account_id = account_id unless account_id == SKIP @account_number = account_number unless account_number == SKIP @driver_name = driver_name unless driver_name == SKIP @card_id = card_id unless card_id == SKIP @card_group_id = card_group_id unless card_group_id == SKIP @card_pan = card_pan unless card_pan == SKIP @product_code = product_code unless product_code == SKIP @product_name = product_name unless product_name == SKIP @site_code = site_code unless site_code == SKIP @incoming_site_number = incoming_site_number unless incoming_site_number == SKIP @invoice_date = invoice_date unless invoice_date == SKIP @invoice_number = invoice_number unless invoice_number == SKIP unless purchased_in_country_code == SKIP @purchased_in_country_code = purchased_in_country_code end @purchased_in_country = purchased_in_country unless purchased_in_country == SKIP @site_group_id = site_group_id unless site_group_id == SKIP unless vehicle_registration_number == SKIP @vehicle_registration_number = vehicle_registration_number end @fee_type_id = fee_type_id unless fee_type_id == SKIP @line_item_description = line_item_description unless line_item_description == SKIP @cards = cards unless cards == SKIP @sort_order = sort_order unless sort_order == SKIP @from_date = from_date unless from_date == SKIP @to_date = to_date unless to_date == SKIP @period = period unless period == SKIP @posting_date_from = posting_date_from unless posting_date_from == SKIP @posting_date_to = posting_date_to unless posting_date_to == SKIP @transaction_item_id = transaction_item_id unless transaction_item_id == SKIP @fuel_only = fuel_only unless fuel_only == SKIP @include_fees = include_fees unless include_fees == SKIP @is_multipayer = is_multipayer unless is_multipayer == SKIP @valid_invoice_date_only = valid_invoice_date_only unless valid_invoice_date_only == SKIP @invoice_from_date = invoice_from_date unless invoice_from_date == SKIP @invoice_to_date = invoice_to_date unless invoice_to_date == SKIP unless hosting_collecting_company_number == SKIP @hosting_collecting_company_number = hosting_collecting_company_number end @search = search unless search == SKIP @transaction_id = transaction_id unless transaction_id == SKIP end |
Instance Attribute Details
#account_id ⇒ Integer
Account Id (GFN customer id)
30 31 32 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 30 def account_id @account_id end |
#account_number ⇒ String
Account Number of the selected account.
34 35 36 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 34 def account_number @account_number end |
#card_group_id ⇒ Integer
Card Group Id in GFN
46 47 48 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 46 def card_group_id @card_group_id end |
#card_id ⇒ Integer
Unique Card Id in the Shell Card Platform
42 43 44 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 42 def card_id @card_id end |
#card_pan ⇒ String
Full Card PAN
50 51 52 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 50 def card_pan @card_pan end |
#cards ⇒ Array[Integer]
This entity accepts the list of CardId to filter in the response. Note: The number of cardId allowed to be passed in the request is configurable to a maximum of 500 cards.
104 105 106 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 104 def cards @cards end |
#col_co_code ⇒ String
Collecting Company Code (Shell Code) of the selected payer.
14 15 16 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 14 def col_co_code @col_co_code end |
#col_co_id ⇒ Integer
The Collecting Company Id in the Shell Card Platform.
18 19 20 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 18 def col_co_id @col_co_id end |
#driver_name ⇒ String
Driver Name (of Card record)
38 39 40 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 38 def driver_name @driver_name end |
#fee_type_id ⇒ Integer
Card Id (i.e. Unique Card Id in GFN)
94 95 96 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 94 def fee_type_id @fee_type_id end |
#from_date ⇒ String
From transaction delivery date
114 115 116 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 114 def from_date @from_date end |
#fuel_only ⇒ TrueClass | FalseClass
Is FuelOnly indicator
138 139 140 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 138 def fuel_only @fuel_only end |
#hosting_collecting_company_number ⇒ String
Hosting Collecting Company Number of the selected payer.
172 173 174 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 172 def hosting_collecting_company_number @hosting_collecting_company_number end |
#include_fees ⇒ TrueClass | FalseClass
When passed as ‘true’ then all sales items along with fees will be included in the response and the follwoing filteres will be ignored
-
InvoiceNumber
-
InvoiceDate
-
PostingDateFrom
-
PostingDateTo
147 148 149 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 147 def include_fees @include_fees end |
#incoming_site_number ⇒ String
Site Code as configured in GFN
66 67 68 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 66 def incoming_site_number @incoming_site_number end |
#invoice_date ⇒ String
Returns the billed transaction for the given invoice date
70 71 72 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 70 def invoice_date @invoice_date end |
#invoice_from_date ⇒ String
Invoice From Date, this is a search criterion to filter invoiced transactions with invoice date from this date.
163 164 165 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 163 def invoice_from_date @invoice_from_date end |
#invoice_number ⇒ String
Returns the billed transaction for the given invoice number
74 75 76 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 74 def invoice_number @invoice_number end |
#invoice_status ⇒ PricedTransactionReqV2InvoiceStatusEnum
The Collecting Company Id in the Shell Card Platform.
22 23 24 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 22 def invoice_status @invoice_status end |
#invoice_to_date ⇒ String
Invoice To Date, this is a search criterion to filter invoiced transactions with invoice date until this date.
168 169 170 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 168 def invoice_to_date @invoice_to_date end |
#is_multipayer ⇒ TrueClass | FalseClass
If true then returns all the data linked tothe payer group of the provided PayerNumberin the request
152 153 154 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 152 def is_multipayer @is_multipayer end |
#line_item_description ⇒ String
Item identifier in the transaction.
98 99 100 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 98 def line_item_description @line_item_description end |
#payer_number ⇒ String
Payer Number of the selected payer.
26 27 28 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 26 def payer_number @payer_number end |
#period ⇒ PricedTransactionReqV2PeriodEnum
To transaction delivery date
122 123 124 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 122 def period @period end |
#posting_date_from ⇒ String
Transaction posting start date and time
126 127 128 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 126 def posting_date_from @posting_date_from end |
#posting_date_to ⇒ String
Transaction posting end date and time
130 131 132 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 130 def posting_date_to @posting_date_to end |
#product_code ⇒ String
Product Code – Global as per GFN configuration
54 55 56 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 54 def product_code @product_code end |
#product_name ⇒ String
Product Name – Global as per GFN configuration
58 59 60 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 58 def product_name @product_name end |
#purchased_in_country ⇒ String
Network Delco PurchasedCountryName
82 83 84 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 82 def purchased_in_country @purchased_in_country end |
#purchased_in_country_code ⇒ String
Purchased InCountryCode
78 79 80 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 78 def purchased_in_country_code @purchased_in_country_code end |
#search ⇒ String
Search based on DriverName or VRN
176 177 178 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 176 def search @search end |
#site_code ⇒ String
Site Code in GFN
62 63 64 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 62 def site_code @site_code end |
#site_group_id ⇒ Integer
Site Group Id in GFN
86 87 88 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 86 def site_group_id @site_group_id end |
#sort_order ⇒ PricedTransactionReqV2SortOrderEnum
This entity accepts the list of CardId to filter in the response. Note: The number of cardId allowed to be passed in the request is configurable to a maximum of 500 cards.
110 111 112 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 110 def sort_order @sort_order end |
#to_date ⇒ String
To transaction delivery date
118 119 120 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 118 def to_date @to_date end |
#transaction_id ⇒ String
Unique id of the transaction that may include one or more salesitems
180 181 182 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 180 def transaction_id @transaction_id end |
#transaction_item_id ⇒ String
Unique id of the transaction that may include one or more salesitems
134 135 136 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 134 def transaction_item_id @transaction_item_id end |
#valid_invoice_date_only ⇒ TrueClass | FalseClass
When passed as ‘True’ the transactions records with report date not equal to 9999-12-30 will be returned. When passed as ‘False’ the above condition will not be checked.
158 159 160 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 158 def valid_invoice_date_only @valid_invoice_date_only end |
#vehicle_registration_number ⇒ String
Vehicle Registration (of Card record)
90 91 92 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 90 def vehicle_registration_number @vehicle_registration_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 376 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. col_co_code = hash.key?('ColCoCode') ? hash['ColCoCode'] : nil invoice_status = hash.key?('InvoiceStatus') ? hash['InvoiceStatus'] : nil payer_number = hash.key?('PayerNumber') ? hash['PayerNumber'] : nil col_co_id = hash.key?('ColCoId') ? hash['ColCoId'] : SKIP account_id = hash.key?('AccountId') ? hash['AccountId'] : SKIP account_number = hash.key?('AccountNumber') ? hash['AccountNumber'] : SKIP driver_name = hash.key?('DriverName') ? hash['DriverName'] : SKIP card_id = hash.key?('CardId') ? hash['CardId'] : SKIP card_group_id = hash.key?('CardGroupId') ? hash['CardGroupId'] : SKIP card_pan = hash.key?('CardPAN') ? hash['CardPAN'] : SKIP product_code = hash.key?('ProductCode') ? hash['ProductCode'] : SKIP product_name = hash.key?('ProductName') ? hash['ProductName'] : SKIP site_code = hash.key?('SiteCode') ? hash['SiteCode'] : SKIP incoming_site_number = hash.key?('IncomingSiteNumber') ? hash['IncomingSiteNumber'] : SKIP invoice_date = hash.key?('InvoiceDate') ? hash['InvoiceDate'] : SKIP invoice_number = hash.key?('InvoiceNumber') ? hash['InvoiceNumber'] : SKIP purchased_in_country_code = hash.key?('PurchasedInCountryCode') ? hash['PurchasedInCountryCode'] : SKIP purchased_in_country = hash.key?('PurchasedInCountry') ? hash['PurchasedInCountry'] : SKIP site_group_id = hash.key?('SiteGroupId') ? hash['SiteGroupId'] : SKIP vehicle_registration_number = hash.key?('VehicleRegistrationNumber') ? hash['VehicleRegistrationNumber'] : SKIP fee_type_id = hash.key?('FeeTypeId') ? hash['FeeTypeId'] : SKIP line_item_description = hash.key?('LineItemDescription') ? hash['LineItemDescription'] : SKIP cards = hash.key?('Cards') ? hash['Cards'] : SKIP sort_order = hash.key?('SortOrder') ? hash['SortOrder'] : SKIP from_date = hash.key?('FromDate') ? hash['FromDate'] : SKIP to_date = hash.key?('ToDate') ? hash['ToDate'] : SKIP period = hash.key?('Period') ? hash['Period'] : SKIP posting_date_from = hash.key?('PostingDateFrom') ? hash['PostingDateFrom'] : SKIP posting_date_to = hash.key?('PostingDateTo') ? hash['PostingDateTo'] : SKIP transaction_item_id = hash.key?('TransactionItemId') ? hash['TransactionItemId'] : SKIP fuel_only = hash['FuelOnly'] ||= false include_fees = hash.key?('IncludeFees') ? hash['IncludeFees'] : SKIP is_multipayer = hash.key?('IsMultipayer') ? hash['IsMultipayer'] : SKIP valid_invoice_date_only = hash['ValidInvoiceDateOnly'] ||= false invoice_from_date = hash.key?('InvoiceFromDate') ? hash['InvoiceFromDate'] : SKIP invoice_to_date = hash.key?('InvoiceToDate') ? hash['InvoiceToDate'] : SKIP hosting_collecting_company_number = hash.key?('HostingCollectingCompanyNumber') ? hash['HostingCollectingCompanyNumber'] : SKIP search = hash.key?('Search') ? hash['Search'] : SKIP transaction_id = hash.key?('TransactionId') ? hash['TransactionId'] : SKIP # Create object from extracted values. Filters.new(col_co_code, invoice_status, payer_number, col_co_id, account_id, account_number, driver_name, card_id, card_group_id, card_pan, product_code, product_name, site_code, incoming_site_number, invoice_date, invoice_number, purchased_in_country_code, purchased_in_country, site_group_id, vehicle_registration_number, fee_type_id, line_item_description, cards, sort_order, from_date, to_date, period, posting_date_from, posting_date_to, transaction_item_id, fuel_only, include_fees, is_multipayer, valid_invoice_date_only, invoice_from_date, invoice_to_date, hosting_collecting_company_number, search, transaction_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 183 def self.names @_hash = {} if @_hash.nil? @_hash['col_co_code'] = 'ColCoCode' @_hash['col_co_id'] = 'ColCoId' @_hash['invoice_status'] = 'InvoiceStatus' @_hash['payer_number'] = 'PayerNumber' @_hash['account_id'] = 'AccountId' @_hash['account_number'] = 'AccountNumber' @_hash['driver_name'] = 'DriverName' @_hash['card_id'] = 'CardId' @_hash['card_group_id'] = 'CardGroupId' @_hash['card_pan'] = 'CardPAN' @_hash['product_code'] = 'ProductCode' @_hash['product_name'] = 'ProductName' @_hash['site_code'] = 'SiteCode' @_hash['incoming_site_number'] = 'IncomingSiteNumber' @_hash['invoice_date'] = 'InvoiceDate' @_hash['invoice_number'] = 'InvoiceNumber' @_hash['purchased_in_country_code'] = 'PurchasedInCountryCode' @_hash['purchased_in_country'] = 'PurchasedInCountry' @_hash['site_group_id'] = 'SiteGroupId' @_hash['vehicle_registration_number'] = 'VehicleRegistrationNumber' @_hash['fee_type_id'] = 'FeeTypeId' @_hash['line_item_description'] = 'LineItemDescription' @_hash['cards'] = 'Cards' @_hash['sort_order'] = 'SortOrder' @_hash['from_date'] = 'FromDate' @_hash['to_date'] = 'ToDate' @_hash['period'] = 'Period' @_hash['posting_date_from'] = 'PostingDateFrom' @_hash['posting_date_to'] = 'PostingDateTo' @_hash['transaction_item_id'] = 'TransactionItemId' @_hash['fuel_only'] = 'FuelOnly' @_hash['include_fees'] = 'IncludeFees' @_hash['is_multipayer'] = 'IsMultipayer' @_hash['valid_invoice_date_only'] = 'ValidInvoiceDateOnly' @_hash['invoice_from_date'] = 'InvoiceFromDate' @_hash['invoice_to_date'] = 'InvoiceToDate' @_hash['hosting_collecting_company_number'] = 'HostingCollectingCompanyNumber' @_hash['search'] = 'Search' @_hash['transaction_id'] = 'TransactionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 271 def self.nullables %w[ col_co_code payer_number account_id account_number driver_name card_group_id card_pan product_code product_name site_code incoming_site_number invoice_date invoice_number purchased_in_country_code purchased_in_country site_group_id vehicle_registration_number fee_type_id line_item_description from_date to_date posting_date_from posting_date_to transaction_item_id fuel_only include_fees invoice_from_date invoice_to_date hosting_collecting_company_number search transaction_id ] end |
.optionals ⇒ Object
An array for optional fields
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 229 def self.optionals %w[ col_co_id account_id account_number driver_name card_id card_group_id card_pan product_code product_name site_code incoming_site_number invoice_date invoice_number purchased_in_country_code purchased_in_country site_group_id vehicle_registration_number fee_type_id line_item_description cards sort_order from_date to_date period posting_date_from posting_date_to transaction_item_id fuel_only include_fees is_multipayer valid_invoice_date_only invoice_from_date invoice_to_date hosting_collecting_company_number search transaction_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 497 def inspect class_name = self.class.name.split('::').last "<#{class_name} col_co_code: #{@col_co_code.inspect}, col_co_id: #{@col_co_id.inspect},"\ " invoice_status: #{@invoice_status.inspect}, payer_number: #{@payer_number.inspect},"\ " account_id: #{@account_id.inspect}, account_number: #{@account_number.inspect},"\ " driver_name: #{@driver_name.inspect}, card_id: #{@card_id.inspect}, card_group_id:"\ " #{@card_group_id.inspect}, card_pan: #{@card_pan.inspect}, product_code:"\ " #{@product_code.inspect}, product_name: #{@product_name.inspect}, site_code:"\ " #{@site_code.inspect}, incoming_site_number: #{@incoming_site_number.inspect},"\ " invoice_date: #{@invoice_date.inspect}, invoice_number: #{@invoice_number.inspect},"\ " purchased_in_country_code: #{@purchased_in_country_code.inspect}, purchased_in_country:"\ " #{@purchased_in_country.inspect}, site_group_id: #{@site_group_id.inspect},"\ " vehicle_registration_number: #{@vehicle_registration_number.inspect}, fee_type_id:"\ " #{@fee_type_id.inspect}, line_item_description: #{@line_item_description.inspect}, cards:"\ " #{@cards.inspect}, sort_order: #{@sort_order.inspect}, from_date: #{@from_date.inspect},"\ " to_date: #{@to_date.inspect}, period: #{@period.inspect}, posting_date_from:"\ " #{@posting_date_from.inspect}, posting_date_to: #{@posting_date_to.inspect},"\ " transaction_item_id: #{@transaction_item_id.inspect}, fuel_only: #{@fuel_only.inspect},"\ " include_fees: #{@include_fees.inspect}, is_multipayer: #{@is_multipayer.inspect},"\ " valid_invoice_date_only: #{@valid_invoice_date_only.inspect}, invoice_from_date:"\ " #{@invoice_from_date.inspect}, invoice_to_date: #{@invoice_to_date.inspect},"\ " hosting_collecting_company_number: #{@hosting_collecting_company_number.inspect}, search:"\ " #{@search.inspect}, transaction_id: #{@transaction_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/shell_data_reporting_ap_is/models/filters.rb', line 474 def to_s class_name = self.class.name.split('::').last "<#{class_name} col_co_code: #{@col_co_code}, col_co_id: #{@col_co_id}, invoice_status:"\ " #{@invoice_status}, payer_number: #{@payer_number}, account_id: #{@account_id},"\ " account_number: #{@account_number}, driver_name: #{@driver_name}, card_id: #{@card_id},"\ " card_group_id: #{@card_group_id}, card_pan: #{@card_pan}, product_code: #{@product_code},"\ " product_name: #{@product_name}, site_code: #{@site_code}, incoming_site_number:"\ " #{@incoming_site_number}, invoice_date: #{@invoice_date}, invoice_number:"\ " #{@invoice_number}, purchased_in_country_code: #{@purchased_in_country_code},"\ " purchased_in_country: #{@purchased_in_country}, site_group_id: #{@site_group_id},"\ " vehicle_registration_number: #{@vehicle_registration_number}, fee_type_id:"\ " #{@fee_type_id}, line_item_description: #{@line_item_description}, cards: #{@cards},"\ " sort_order: #{@sort_order}, from_date: #{@from_date}, to_date: #{@to_date}, period:"\ " #{@period}, posting_date_from: #{@posting_date_from}, posting_date_to:"\ " #{@posting_date_to}, transaction_item_id: #{@transaction_item_id}, fuel_only:"\ " #{@fuel_only}, include_fees: #{@include_fees}, is_multipayer: #{@is_multipayer},"\ " valid_invoice_date_only: #{@valid_invoice_date_only}, invoice_from_date:"\ " #{@invoice_from_date}, invoice_to_date: #{@invoice_to_date},"\ " hosting_collecting_company_number: #{@hosting_collecting_company_number}, search:"\ " #{@search}, transaction_id: #{@transaction_id}>" end |